to_transport_representation: Convert an rquery op diagram to a simple representation,...

View source: R/yaml.R

to_transport_representationR Documentation

Convert an rquery op diagram to a simple representation, appropriate for conversion to YAML.

Description

Convert an rquery op diagram to a simple representation, appropriate for conversion to YAML.

Usage

to_transport_representation(ops, ..., convert_named_vectors_to_lists = TRUE)

Arguments

ops

rquery operator dag

...

not used, force later arguments to be by name

convert_named_vectors_to_lists

logical, if TRUE convert named vectors to lists

Value

represenation structure


rquery documentation built on Sept. 9, 2026, 1:06 a.m.